/******************************************************************************
 *
 * Copyright:
 *    (C) 2005 Embedded Artists AB
 *
 * File:
 *    main.c
 *
 * Description:
 *    Sample application that demonstrates how to enable the code protection
 *    mechanism.
 *
 *****************************************************************************/

/******************************************************************************
 * Includes
 *****************************************************************************/
#include "general.h"
#include <lpc2xxx.h>
#include <printf_P.h>
#include <ea_init.h>
#include <consol.h>
#include "startup/config.h"
#include "iap_code/iap.h"


/*****************************************************************************
 * Public function prototypes
 ****************************************************************************/
int main(void);

/*****************************************************************************
 * Implementation of public functions
 ****************************************************************************/

/*****************************************************************************
 *
 * Description:
 *    The main-function. 
 *
 * Returns:
 *    Always 0, since return value is not used.
 *
 ****************************************************************************/
int
main(void)
{
  tU32 bootVersion;
	
  //initialize printf()-functionality
  eaInit();
  
  //print welcome message
  printf("\n\n\n\n");
  printf("\n*********************************************************");
  printf("\n*");
  printf("\n* (C) 2005 Embedded Artists AB");
  printf("\n*");
  printf("\n* Welcome to this program that demonstrates how to enable");
  printf("\n* the code protection functionality.");
  printf("\n*");
  printf("\n*********************************************************\n");

  //information text...
  printf("\nExcerpt from User's Manual:\n");
  printf("\nCode read protection is enabled by programming the flash");
  printf("\naddress location 0x1FC (User flash sector 0) with value");
  printf("\n0x8765 4321 (2271560481 Decimal). Address 0x1FC is used to");
  printf("\nallow some room for the fiq exception handler. When the");
  printf("\ncode read protection is enabled the JTAG debug port,");
  printf("\nexternal memory boot and the following ISP commands are");
  printf("\ndisabled:");
  printf("\n * Read Memory");
  printf("\n * Write to RAM");
  printf("\n * Go");
  printf("\n * Copy RAM to Flash");
  printf("\n\nThe ISP commands mentioned above terminate with return");
  printf("\ncode CODE_READ_PROTECTION_ENABLED. The ISP erase command");
  printf("\nonly allows erasure of all user sectors when the code");
  printf("\nread protection is enabled. This limitation does not exist");
  printf("\nif the code read protection is not enabled. IAP commands");
  printf("\nare not affected by the code read protection.");
  printf("\n\nImportant: CRP is active/inactive once the device has");
  printf("\ngone through a power cycle.");
  
  //get boot code version
  bootVersion = iapReadBootVer();
  printf("\n\nBoot code version: %d.%d", bootVersion >> 8, bootVersion & 0xff);

  //check if below ver: 1.6 (= code protection is not possible)
  if (((bootVersion >> 8) == 1) && ((bootVersion & 0xff) < 6))
  {
    printf("\nUnfortunately, code protection is not available on this chip!!!");
    printf("(because boot code version is less than ver: 1.6)");
  }
  else
  {
    printf("\nCode protection is available on this chip! (boot code version >= ver: 1.6)");
    printf("\n\nOBSERVE: You must now erase the entire chip before you can download a new program into the chip!!!");
    printf("\n\nTest with PHILIPS FLASH Utility to read the FLASH memory - it will not work!\n");
  }

  //enter forever loop...
  while(1)
    ;

  return 0;
}
